@@ -1,6 +1,6 @@
 from sage.all_cmdline import *
-from cgt import hyperoctahedral_groups
-import numpy as np
+from . import hyperoctahedral_groups
+from .enums import *
 
 def regular_representation(G, g): 
 	"""regular representation """
@@ -23,4 +23,9 @@ def irreducible_representations(n, signed=False):
 				image = gap.Image(_irrep, sigma)
 				return image if as_gap_matrix else matrix(UniversalCyclotomicField(), image)
 			representations.append(representation)
-		return representations
\ No newline at end of file
+		return representations
+
+
+
+
+
